@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 2013-2018 John W. Eaton
-Copyright (C) 2011-2018 Jacob Dawid
+Copyright (C) 2013-2019 John W. Eaton
+Copyright (C) 2011-2019 Jacob Dawid
 
 This file is part of Octave.
 
@@ -27,18 +27,24 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <QDesktopWidget>
 
+#include "quit.h"
+#include "signal-wrappers.h"
+
+#include "sighandlers.h"
+
 #include "terminal-dock-widget.h"
 #include "resource-manager.h"
+#include "gui-preferences.h"
 
 namespace octave
 {
   terminal_dock_widget::terminal_dock_widget (QWidget *p)
-    : octave_dock_widget (p), m_terminal (QTerminal::create (p))
+    : octave_dock_widget ("TerminalDockWidget", p),
+      m_terminal (QTerminal::create (p))
   {
     m_terminal->setObjectName ("OctaveTerminal");
     m_terminal->setFocusPolicy (Qt::StrongFocus);
 
-    setObjectName ("TerminalDockWidget");
     setWindowIcon (QIcon (":/actions/icons/logo.png"));
     set_title (tr ("Command Window"));
 
@@ -58,8 +64,9 @@ namespace octave
 
     QFont font = QFont ();
     font.setStyleHint (QFont::TypeWriter);
+    QString default_font = settings->value (global_mono_font.key, global_mono_font.def).toString ();
     font.setFamily
-      (settings->value ("terminal/fontName", "Courier New").toString ());
+      (settings->value (cs_font.key, default_font).toString ());
     font.setPointSize (settings->value ("terminal/fontSize", 10).toInt ());
 
     QFontMetrics metrics(font);
@@ -103,6 +110,17 @@ namespace octave
 
   void terminal_dock_widget::terminal_interrupt (void)
   {
-    emit interrupt_signal ();
+    // FIXME: Protect with mutex?
+
+    octave_signal_caught = 1;
+    octave_interrupt_state++;
+
+    // Send SIGINT to all other processes in our process group.
+    // This is needed to interrupt calls to system (), for example.
+
+    int sigint;
+    octave_get_sig_number ("SIGINT", &sigint);
+
+    octave_kill_wrapper (0, sigint);
   }
 }
