@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1993-2018 John W. Eaton
+Copyright (C) 1993-2019 John W. Eaton
 
 This file is part of Octave.
 
@@ -166,7 +166,7 @@ verror (bool save_last_error, std::ostream& os,
 
   std::ostringstream output_buf;
 
-  octave_vformat (output_buf, fmt, args);
+  octave::vformat (output_buf, fmt, args);
 
   std::string base_msg = output_buf.str ();
 
@@ -368,9 +368,11 @@ maybe_enter_debugger (octave::execution_exception& e,
       frame.protect_var (Vdebug_on_error);
       Vdebug_on_error = false;
 
-      octave::tree_evaluator::debug_mode = true;
+      octave::tree_evaluator& tw
+        = octave::__get_evaluator__ ("maybe_enter_debugger");
 
-      octave::tree_evaluator::current_frame = cs.current_frame ();
+      tw.debug_mode (true);
+      tw.current_frame (cs.current_frame ());
 
       if (show_stack_trace)
         {
@@ -384,7 +386,10 @@ maybe_enter_debugger (octave::execution_exception& e,
             }
         }
 
-      do_keyboard (octave_value_list ());
+      octave::input_system& input_sys
+        = octave::__get_input_system__ ("maybe_enter_debugger");
+
+      input_sys.keyboard ();
     }
 }
 
@@ -400,7 +405,7 @@ vwarning (const char *name, const char *id, const char *fmt, va_list args)
 
   std::ostringstream output_buf;
 
-  octave_vformat (output_buf, fmt, args);
+  octave::vformat (output_buf, fmt, args);
 
   // FIXME: we really want to capture the message before it has all the
   //        formatting goop attached to it.  We probably also want just the
@@ -477,21 +482,6 @@ usage_1 (const char *id, const char *fmt, va_list args)
   usage_1 (e, id, fmt, args);
 }
 
-void
-vusage (const char *fmt, va_list args)
-{
-  usage_1 ("", fmt, args);
-}
-
-void
-usage (const char *fmt, ...)
-{
-  va_list args;
-  va_start (args, fmt);
-  usage_1 ("", fmt, args);
-  va_end (args);
-}
-
 void
 vusage_with_id (const char *id, const char *fmt, va_list args)
 {
@@ -782,11 +772,16 @@ warning_1 (const char *id, const char *fmt, va_list args)
           frame.protect_var (Vdebug_on_warning);
           Vdebug_on_warning = false;
 
-          octave::tree_evaluator::debug_mode = true;
+          octave::tree_evaluator& tw
+            = octave::__get_evaluator__ ("warning_1");
 
-          octave::tree_evaluator::current_frame = cs.current_frame ();
+          tw.debug_mode (true);
+          tw.current_frame (cs.current_frame ());
 
-          do_keyboard (octave_value_list ());
+          octave::input_system& input_sys
+            = octave::__get_input_system__ ("warning_1");
+
+          input_sys.keyboard ();
         }
     }
 }
@@ -977,7 +972,7 @@ handle_message (error_fun f, const char *id, const char *msg,
 {
   std::string retval;
 
-  std::string tstr;
+  std::string tmpstr;
 
   if (args.length () > 0)
     {
@@ -993,20 +988,18 @@ handle_message (error_fun f, const char *id, const char *msg,
 
       if (arg.is_defined ())
         {
-          if (arg.is_string ())
-            {
-              tstr = arg.string_value ();
-              msg = tstr.c_str ();
-
-              if (! msg)
-                return retval;
-            }
-          else if (arg.isempty ())
+          if (arg.isempty ())
             return retval;
+          else if (arg.is_string ())
+            {
+              tmpstr = arg.string_value ();  // 2-stage assignment required
+              msg = tmpstr.c_str ();         // in order to generate pointer
+                                             // to valid memory.
+            }
         }
     }
 
-// Ugh.
+  // Ugh.
 
   size_t len = strlen (msg);
 
@@ -1435,21 +1428,19 @@ DEFMETHOD (warning, interp, args, nargout,
 @deftypefnx {} {} warning ("error", @var{id})
 @deftypefnx {} {} warning ("query", @var{id})
 @deftypefnx {} {} warning (@var{state}, @var{id}, "local")
-@deftypefnx {} {} warning (@var{stin})
-@deftypefnx {} {@var{stout} =} warning (@dots{})
-@deftypefnx {} {@var{mode_st} =} warning (@var{state}, @var{mode})
-@deftypefnx {} {} warning (@var{mode_st})
+@deftypefnx {} {} warning (@var{warning_struct})
+@deftypefnx {} {@var{warning_struct} =} warning (@dots{})
+@deftypefnx {} {} warning (@var{state}, @var{mode})
 
-Display a warning message or control the behavior of Octave's warning
-system.
+Display a warning message or control the behavior of Octave's warning system.
 
-The first call form uses a template @var{template} and optional
-additional arguments to display a message on the @code{stderr} stream.
-The message is formatted using the same rules as the @code{printf} family
-of functions (@pxref{Formatted Output}) and prefixed by the character
-string @samp{warning: }.  You should use this function when you want to
-notify the user of an unusual condition, but only when it makes sense for
-your program to go on.  For example:
+The first call form uses a template @var{template} and optional additional
+arguments to display a message on the @code{stderr} stream.  The message is
+formatted using the same rules as the @code{printf} family of functions
+(@pxref{Formatted Output}) and prefixed by the character string
+@w{@samp{warning: }}.  You should use this function when you want to notify the
+user of an unusual condition, but only when it makes sense for your program to
+go on.  For example:
 
 @example
 @group
@@ -1457,6 +1448,12 @@ warning ("foo: maybe something wrong here");
 @end group
 @end example
 
+If the warning message does not end with a newline character, Octave will
+print a traceback of all the function calls leading to the warning.  If the
+warning message does end in a newline character, Octave will suppress the
+traceback messages as it returns control to the top level.  For more details
+and examples, see @ref{XREFerror,,error}.
+
 The optional warning identifier @var{id} allows users to enable or disable
 warnings tagged by this identifier.  A message identifier is a string of the
 form @qcode{"NAMESPACE:WARNING-NAME"}.  Octave's own warnings use the
@@ -1475,9 +1472,9 @@ The first input argument must be a string @var{state} (@qcode{"on"},
 @qcode{"off"}, @qcode{"error"}, or @qcode{"query"}) followed by an optional
 warning identifier @var{id} or @qcode{"all"} (default).
 
-The optional output argument @var{stout} is a structure or structure array
-with fields @qcode{"state"} and @qcode{"identifier"}.  The @var{state} argument
-may have the following values:
+The optional output argument @var{warning_struct} is a structure or structure
+array with fields @qcode{"state"} and @qcode{"identifier"}.  The @var{state}
+argument may have the following values:
 
 @table @asis
 @item @qcode{"on"}|@qcode{"off"}:
@@ -1492,10 +1489,10 @@ previous state @var{stout}.
 Return the current state of warnings identified by @var{id}.
 @end table
 
-A structure or structure array @var{stin}, with fields @qcode{"state"} and
-@qcode{"identifier"}, may be passed to achieve equivalent results.  The
-following example shows how to temporarily disable a warning and then restore
-its original state:
+A structure or structure array @var{warning_struct}, with fields
+@qcode{"state"} and @qcode{"identifier"}, may be given as an input to achieve
+equivalent results.  The following example shows how to temporarily disable a
+warning and then restore its original state:
 
 @example
 @group
@@ -1534,12 +1531,12 @@ enable/disable the display of additional information after the warning message
 In this case the @var{state} argument may only be @qcode{"on"} or
 @qcode{"off"}.
 
-Implementation Note: For compatibility with @sc{matlab}, escape
-sequences in @var{template} (e.g., @qcode{"@xbackslashchar{}n"} =>
-newline) are processed regardless of whether @var{template} has been defined
-with single quotes, as long as there are two or more input arguments.  To
-disable escape sequence expansion use a second backslash before the sequence
-(e.g., @qcode{"@xbackslashchar{}@xbackslashchar{}n"}) or use the
+Implementation Note: For compatibility with @sc{matlab}, escape sequences in
+@var{template} (e.g., @qcode{"@xbackslashchar{}n"} => newline) are processed
+regardless of whether @var{template} has been defined with single quotes, as
+long as there are two or more input arguments.  To disable escape sequence
+expansion use a second backslash before the sequence (e.g.,
+@qcode{"@xbackslashchar{}@xbackslashchar{}n"}) or use the
 @code{regexptranslate} function.
 @seealso{warning_ids, lastwarn, error}
 @end deftypefn */)
