@@ -1,22 +1,22 @@
-## Copyright (C) 2010-2017 John W. Eaton
+## Copyright (C) 2010-2019 John W. Eaton
 ## Copyright (C) 2010 VZLU Prague
-## Copyright (C) 2017 Colin B. Macdonald
+## Copyright (C) 2017-2019 Colin B. Macdonald
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{txt} =} __unimplemented__ (@var{fcn})
@@ -44,36 +44,21 @@ function txt = __unimplemented__ (fcn)
   switch (fcn)
     case {"avifile", "aviinfo", "aviread"}
       txt = ["Basic video file support is provided in the video package.  ", ...
-             "See @url{http://octave.sf.net/video/}."];
+             "See @url{https://octave.sourceforge.io/video/}."];
 
     case "exifread"
       txt = ["exifread is deprecated.  " ...
              "The functionality is available in the imfinfo function."];
 
-    case "gsvd"
-      txt = ["gsvd is not currently part of core Octave.  ", ...
-             "See the linear-algebra package at ", ...
-             "@url{http://octave.sourceforge.net/linear-algebra/}."];
-
     case "funm"
       txt = ["funm is not currently part of core Octave.  ", ...
              "See the linear-algebra package at ", ...
-             "@url{http://octave.sourceforge.net/linear-algebra/}."];
+             "@url{https://octave.sourceforge.io/linear-algebra/}."];
 
     case "griddedInterpolant"
       txt = ["griddedInterpolant is not implemented.  ", ...
              "Consider using griddata."];
 
-    case "integral"
-      txt = ["Octave provides many routines for 1-D numerical integration.  ", ...
-             "Consider quadcc, quad, quadv, quadl, quadgk."];
-
-    case "integral2"
-      txt = ["integral2 is not implemented.  Consider using dblquad."];
-
-    case "integral3"
-      txt = ["integral3 is not implemented.  Consider using triplequad"];
-
     case "linprog"
       txt = ["Octave does not currently provide linprog.  ", ...
              "Linear programming problems may be solved using @code{glpk}.  ", ...
@@ -81,29 +66,26 @@ function txt = __unimplemented__ (fcn)
 
     case "matlabrc"
       txt = ["matlabrc is not implemented.  ", ...
-             'Octave uses the file ".octaverc" instead.'];
+             "Octave uses the file '.octaverc' instead."];
 
     case {"ode113", "ode15i", "ode15s", "ode23s", "ode23t", "ode23tb"}
       txt = ["Octave provides lsode and ode45 for solving differential equations. ", ...
              "For more information try @code{help lsode}, @code{help ode45}.  ", ...
              "Matlab-compatible ODE functions are provided by the odepkg ", ...
-             "package.  See @url{http://octave.sourceforge.net/odepkg/}."];
+             "package.  See @url{https://octave.sourceforge.io/odepkg/}."];
 
     case "polarplot"
       txt = ["polarplot is not implemented.  Consider using polar."];
 
     case "startup"
-      txt = ["startup is not implemented.  ", ...
-             'Octave uses the file ".octaverc" instead.'];
-
-    case "quad2d"
-      txt = ["quad2d is not implemented.  Consider using dblquad."];
+      txt = ["'startup.m' is a user startup and configuration script.  ", ...
+             "Try @code{doc startup} for more information."];
 
     case {"xlsread", "xlsfinfo", "xlswrite", "wk1read", "wk1finfo", "wk1write"}
       txt = ["Functions for spreadsheet style I/O ", ...
              "(.xls .xlsx .sxc .ods .dbf .wk1 etc.) " , ...
              "are provided in the io package. ", ...
-             "See @url{http://octave.sf.net/io/}."];
+             "See @url{https://octave.sourceforge.io/io/}."];
 
     ## control system
     case {"absorbDelay", "allmargin", "append", "augstate", "balreal", ...
@@ -385,97 +367,118 @@ function txt = __unimplemented__ (fcn)
       txt = check_package (fcn, "signal");
 
     ## statistics
-    case {"addedvarplot", "addlevels", "addTerms", "adtest", ...
-          "andrewsplot", "anova1", "anova2", "anovan", "ansaribradley", ...
-          "aoctool", "barttest", "bbdesign", "betafit", "betalike", ...
-          "betastat", "binofit", "binostat", "biplot", "bootci", "bootstrp", ...
-          "boxplot", "candexch", "candgen", "canoncorr", "capability", ...
-          "capaplot", "caseread", "casewrite", "ccdesign", "cdf", ...
-          "cdfplot", "cell2dataset", "chi2gof", "chi2stat", "cholcov", ...
+    case {"addedvarplot", "addlevels", "addTerms", "adtest", "andrewsplot", ...
+          "anova", "anova1", "anova2", "anovan", "ansaribradley", ...
+          "aoctool", "bartlett_test", "barttest", "bbdesign", "betacdf", ...
+          "betafit", "betainv", "betalike", "betapdf", "betarnd", ...
+          "betastat", "binocdf", "binofit", "binoinv", "binopdf", ...
+          "binornd", "binostat", "biplot", "bootci", "bootstrp", "boxplot", ...
+          "candexch", "candgen", "canoncorr", "capability", "capaplot", ...
+          "caseread", "casewrite", "cauchy_cdf", "cauchy_inv", ...
+          "cauchy_pdf", "cauchy_rnd", "ccdesign", "cdf", "cdfplot", ...
+          "cell2dataset", "chi2cdf", "chi2gof", "chi2inv", "chi2pdf", ...
+          "chi2rnd", "chi2stat", "chisquare_test_homogeneity", ...
+          "chisquare_test_independence", "cholcov", ...
           "ClassificationBaggedEnsemble", "ClassificationDiscriminant", ...
           "ClassificationEnsemble", "ClassificationKNN", ...
           "ClassificationPartitionedEnsemble", ...
           "ClassificationPartitionedModel", "ClassificationTree", ...
-          "classify", "classregtree", "cluster", "clusterdata", "cmdscale", ...
-          "coefCI", "coefTest",  ...
-          "combnk", "compact", ...
+          "classify", "classregtree", "cloglog", "cluster", "clusterdata", ...
+          "cmdscale", "coefCI", "coefTest", "combnk", "compact", ...
           "CompactClassificationDiscriminant", ...
           "CompactClassificationEnsemble", "CompactClassificationTree", ...
           "CompactRegressionEnsemble", "CompactRegressionTree", ...
           "CompactTreeBagger", "compare", "confusionmat", "controlchart", ...
           "controlrules", "cophenet", "copulacdf", "copulafit", ...
-          "copulaparam", "copulapdf", "copularnd", "copulastat", "cordexch", ...
-          "corrcov", "covarianceParameters", "coxphfit", "createns", ...
-          "crosstab", "crossval", "cvpartition", "datasample", "dataset", ...
-          "dataset2cell", "dataset2struct", "dataset2table", "datasetfun", ...
-          "daugment", "dcovary", "dendrogram", "designMatrix", ...
-          "devianceTest", "dfittool",  ...
+          "copulaparam", "copulapdf", "copularnd", "copulastat", ...
+          "cordexch", "corrcov", "cor_test", "covarianceParameters", ...
+          "coxphfit", "createns", "crosstab", "crossval", "cvpartition", ...
+          "datasample", "dataset", "dataset2cell", "dataset2struct", ...
+          "dataset2table", "datasetfun", "daugment", "dcovary", ...
+          "dendrogram", "designMatrix", "devianceTest", "dfittool", ...
           "disttool", "droplevels", "dummyvar", "dwtest", "ecdf", ...
           "ecdfhist", "evalclusters", "evcdf", "evfit", "evinv", "evlike", ...
-          "evpdf", "evrnd", "evstat", "ExhaustiveSearcher", "expfit", ...
-          "explike", "export", "expstat", "factoran", ...
-          "ff2n", "fitdist", "fitensemble", "fitglm", "fitlm", ...
-          "fitlme", "fitlmematrix", "fitnlm", "fitted", "fixedEffects", ...
-          "fracfact", "fracfactgen", "friedman", "fsurfht", "fullfact", ...
-          "gagerr", "gamfit", "gamlike", "gamstat", ...
-          "GeneralizedLinearModel", "geomean", "geostat", "getlabels", ...
-          "getlevels", "gevcdf", "gevfit", "gevinv", "gevlike", "gevpdf", ...
-          "gevrnd", "gevstat", "gline", "glmfit", "glmval", "glyphplot", ...
+          "evpdf", "evrnd", "evstat", "ExhaustiveSearcher", "expcdf", ...
+          "expfit", "expinv", "explike", "export", "exppdf", "exprnd", ...
+          "expstat", "factoran", "fcdf", "ff2n", "finv", "fitdist", ...
+          "fitensemble", "fitglm", "fitlm", "fitlme", "fitlmematrix", ...
+          "fitnlm", "fitted", "fixedEffects", "fpdf", "fracfact", ...
+          "fracfactgen", "friedman", "frnd", "fsurfht", "fullfact", ...
+          "f_test_regression", "gagerr", "gamcdf", "gamfit", "gaminv", ...
+          "gamlike", "gampdf", "gamrnd", "gamstat", ...
+          "GeneralizedLinearModel", "geocdf", "geoinv", "geomean", ...
+          "geopdf", "geornd", "geostat", "getlabels", "getlevels", ...
+          "gevcdf", "gevfit", "gevinv", "gevlike", "gevpdf", "gevrnd", ...
+          "gevstat", "gline", "glmfit", "glmval", "glyphplot", ...
           "gmdistribution", "gname", "gpcdf", "gpfit", "gpinv", "gplike", ...
           "gplotmatrix", "gppdf", "gprnd", "gpstat", "grp2idx", "grpstats", ...
           "gscatter", "haltonset", "harmmean", "hist3", "histfit", ...
           "hmmdecode", "hmmestimate", "hmmgenerate", "hmmtrain", ...
-          "hmmviterbi", "hougen", "hygestat", "icdf", ...
+          "hmmviterbi", "hotelling_test", "hotelling_test_2", "hougen", ...
+          "hygecdf", "hygeinv", "hygepdf", "hygernd", "hygestat", "icdf", ...
           "inconsistent", "interactionplot", "invpred", "islevel", ...
           "ismissing", "isundefined", "iwishrnd", "jackknife", "jbtest", ...
           "johnsrnd", "join", "KDTreeSearcher", "kmeans", "knnsearch", ...
-          "kruskalwallis", "ksdensity", "kstest", "kstest2", "labels", ...
-          "lasso", "lassoglm", "lassoPlot", "levelcounts", "leverage", ...
-          "lhsdesign", "lhsnorm", "lillietest", "LinearMixedModel", ...
-          "LinearModel", "linhyptest", "linkage", "lognfit", "lognlike", ...
+          "kolmogorov_smirnov_cdf", "kolmogorov_smirnov_test", ...
+          "kolmogorov_smirnov_test_2", "kruskalwallis", ...
+          "kruskal_wallis_test", "ksdensity", "kstest", "kstest2", ...
+          "labels", "laplace_cdf", "laplace_inv", "laplace_pdf", ...
+          "laplace_rnd", "lasso", "lassoglm", "lassoPlot", "levelcounts", ...
+          "leverage", "lhsdesign", "lhsnorm", "lillietest", ...
+          "LinearMixedModel", "LinearModel", "linhyptest", "linkage", ...
+          "logistic_cdf", "logistic_inv", "logistic_pdf", ...
+          "logistic_regression", "logistic_rnd", "logit", "logncdf", ...
+          "lognfit", "logninv", "lognlike", "lognpdf", "lognrnd", ...
           "lognstat", "lsline", "mad", "mahal", "maineffectsplot", ...
-          "makedist", "manova1", "manovacluster", "mat2dataset", "mdscale", ...
-          "mergelevels", "mhsample", "mle", "mlecov", "mnpdf", "mnrfit", ...
-          "mnrnd", "mnrval", "multcompare", "multivarichart", "mvncdf", ...
-          "mvnpdf", "mvnrnd", "mvregress", "mvregresslike", "mvtcdf", ...
-          "mvtpdf", "mvtrnd", "NaiveBayes", "nancov", "nanmax", "nanmean", ...
-          "nanmedian", "nanmin", "nanstd", "nansum", "nanvar", "nbinfit", ...
-          "nbinstat", "ncfcdf", "ncfinv", "ncfpdf", "ncfrnd", "ncfstat", ...
-          "nctcdf", "nctinv", "nctpdf", "nctrnd", "nctstat", "ncx2cdf", ...
-          "ncx2inv", "ncx2pdf", "ncx2rnd", "ncx2stat", "negloglik", ...
-          "nlinfit", "nlintool", "nlmefit", "nlmefitsa", ...
+          "makedist", "manova", "manova1", "manovacluster", "mat2dataset", ...
+          "mcnemar_test", "mdscale", "mergelevels", "mhsample", "mle", ...
+          "mlecov", "mnpdf", "mnrfit", "mnrnd", "mnrval", "multcompare", ...
+          "multivarichart", "mvncdf", "mvnpdf", "mvnrnd", "mvregress", ...
+          "mvregresslike", "mvtcdf", "mvtpdf", "mvtrnd", "NaiveBayes", ...
+          "nancov", "nanmax", "nanmean", "nanmedian", "nanmin", "nanstd", ...
+          "nansum", "nanvar", "nbincdf", "nbinfit", "nbininv", "nbinpdf", ...
+          "nbinrnd", "nbinstat", "ncfcdf", "ncfinv", "ncfpdf", "ncfrnd", ...
+          "ncfstat", "nctcdf", "nctinv", "nctpdf", "nctrnd", "nctstat", ...
+          "ncx2cdf", "ncx2inv", "ncx2pdf", "ncx2rnd", "ncx2stat", ...
+          "negloglik", "nlinfit", "nlintool", "nlmefit", "nlmefitsa", ...
           "nlparci", "nlpredci", "nnmf", "nominal", "NonLinearModel", ...
-          "normfit", "normlike", "normplot", "normspec", "normstat", ...
+          "normcdf", "normfit", "norminv", "normlike", "normpdf", ...
+          "normplot", "normrnd", "normspec", "normstat", ...
           "optimalleaforder", "ordinal", "parallelcoords", "paramci", ...
           "paretotails", "partialcorr", "partialcorri", "pca", "pcacov", ...
-          "pcares", "pdf", "pdist", "pdist2", "pearsrnd", ...
-          "perfcurve", "plotAdded", "plotAdjustedResponse", ...
-          "plotDiagnostics", ...
-          "plotEffects", "plotInteraction", "plotResiduals", ...
-          "plotSlice", ...
-          "plsregress", "poissfit", "poisstat", ...
-          "polyconf", "polytool", "ppca", "predict", ...
-          "princomp", ...
-          "ProbDistUnivKernel", "ProbDistUnivParam", "probplot", ...
-          "procrustes", "proflik", "qrandset", "qrandstream", "random", ...
-          "randomEffects", ...
-          "randsample", "randtool", "rangesearch", "ranksum", "raylcdf", ...
-          "raylfit", "raylinv", "raylpdf", "raylrnd", "raylstat", "rcoplot", ...
-          "refcurve", "refline", "regress", "RegressionBaggedEnsemble", ...
+          "pcares", "pdf", "pdist", "pdist2", "pearsrnd", "perfcurve", ...
+          "plotAdded", "plotAdjustedResponse", "plotDiagnostics", ...
+          "plotEffects", "plotInteraction", "plotResiduals", "plotSlice", ...
+          "plsregress", "poisscdf", "poissfit", "poissinv", "poisspdf", ...
+          "poissrnd", "poisstat", "polyconf", "polytool", "ppca", ...
+          "prctile", "predict", "princomp", "ProbDistUnivKernel", ...
+          "ProbDistUnivParam", "probit", "probplot", "procrustes", ...
+          "proflik", "prop_test_2", "qqplot", "qrandset", "qrandstream", ...
+          "random", "randomEffects", "randsample", "randtool", ...
+          "rangesearch", "ranksum", "raylcdf", "raylfit", "raylinv", ...
+          "raylpdf", "raylrnd", "raylstat", "rcoplot", "refcurve", ...
+          "refline", "regress", "RegressionBaggedEnsemble", ...
           "RegressionEnsemble", "RegressionPartitionedEnsemble", ...
           "RegressionPartitionedModel", "RegressionTree", "regstats", ...
-          "relieff", "removeTerms", "residuals", "response", ...
-          "ridge", "robustdemo", "robustfit", "rotatefactors", "rowexch", ...
-          "rsmdemo", "rstool", "runstest", "sampsizepwr", "scatterhist", ...
-          "sequentialfs", "setlabels", "signrank", "signtest", "silhouette", ...
-          "slicesample", "sobolset", "squareform", "statget", "statset", ...
-          "step", "stepwise", "stepwisefit", "stepwiseglm", ...
-          "stepwiselm", "struct2dataset", "surfht", "svmclassify", ...
-          "svmtrain", "table2dataset", "tabulate", "tblread", "tblwrite", ...
-          "tdfread", "tiedrank", "TreeBagger", "trimmean", "truncate", ...
-          "tstat", "ttest", "ttest2", "unidstat", "unifit", "unifstat", ...
-          "vartest", "vartest2", "vartestn", "wblfit", "wbllike", "wblplot", ...
-          "wblstat", "wishrnd", "x2fx", "xlsread", "xptread", "ztest"}
+          "relieff", "removeTerms", "residuals", "response", "ridge", ...
+          "robustdemo", "robustfit", "rotatefactors", "rowexch", "rsmdemo", ...
+          "rstool", "runstest", "run_test", "sampsizepwr", "scatterhist", ...
+          "sequentialfs", "setlabels", "signrank", "signtest", "sign_test", ...
+          "silhouette", "slicesample", "sobolset", "squareform", "statget", ...
+          "statset", "stdnormal_cdf", "stdnormal_inv", "stdnormal_pdf", ...
+          "stdnormal_rnd", "step", "stepwise", "stepwisefit", ...
+          "stepwiseglm", "stepwiselm", "struct2dataset", "surfht", ...
+          "svmclassify", "svmtrain", "table2dataset", "tabulate", ...
+          "tblread", "tblwrite", "tcdf", "tdfread", "tiedrank", "tinv", ...
+          "tpdf", "TreeBagger", "trimmean", "trnd", "truncate", "tstat", ...
+          "ttest", "ttest2", "t_test", "t_test_2", "t_test_regression", ...
+          "unidcdf", "unidinv", "unidpdf", "unidrnd", "unidstat", ...
+          "unifcdf", "unifinv", "unifit", "unifpdf", "unifrnd", "unifstat", ...
+          "u_test", "vartest", "vartest2", "vartestn", "var_test", ...
+          "wblcdf", "wblfit", "wblinv", "wbllike", "wblpdf", "wblplot", ...
+          "wblrnd", "wblstat", "welch_test", "wienrnd", "wilcoxon_test", ...
+          "wishrnd", "x2fx", "xlsread", "xptread", "ztest", "z_test", ...
+          "z_test_2"}
       txt = check_package (fcn, "statistics");
 
     ## symbolic
@@ -484,15 +487,15 @@ function txt = __unimplemented__ (fcn)
           "digits", "dilog", "dirac", "divisors", "dsolve", "ei", ...
           "ellipticCE", "ellipticCK", "ellipticCPi", "ellipticE", ...
           "ellipticF", "ellipticK", "ellipticPi", "euler", "eulergamma", ...
-          "finverse", "formula", "fresnelc", "fresnels", "funtool", ...
-          "gegenbauerC", "harmonic", "heaviside", "hermiteH", "hypergeom", ...
-          "igamma", "jacobiP", "kroneckerDelta", "kummerU", "laguerreL", ...
-          "legendreP", "logint", "minpoly", "pochhammer", "poles", ...
-          "poly2sym", "polylog", "pretty", "quorem", "rectangularPulse", ...
-          "signIm", "simplify", "sinhint", "sinint", "solve", "ssinint", ...
-          "sym", "sym2poly", "symfun", "sympref", "syms", "symvar", ...
-          "triangularPulse", "vpa", "vpasolve", "whittakerM", "whittakerW", ...
-          "zeta"}
+          "expand", "finverse", "formula", "fresnelc", "fresnels", ...
+          "funtool", "gegenbauerC", "harmonic", "heaviside", "hermiteH", ...
+          "hypergeom", "igamma", "jacobiP", "kroneckerDelta", "kummerU", ...
+          "laguerreL", "legendreP", "logint", "minpoly", "pochhammer", ...
+          "poles", "poly2sym", "polylog", "pretty", "quorem", ...
+          "rectangularPulse", "signIm", "simplify", "sinhint", "sinint", ...
+          "solve", "ssinint", "sym", "sym2poly", "symfun", "sympref", ...
+          "syms", "symvar", "triangularPulse", "vpa", "vpasolve", ...
+          "whittakerM", "whittakerW", "zeta"}
       classes = {"sym", "symfun"};
       txt = check_package (fcn, "symbolic", classes);
 
@@ -514,7 +517,7 @@ function txt = __unimplemented__ (fcn)
 
   if (is_matlab_function)
     txt = [txt, "\n\n@noindent\nPlease read ", ...
-           "@url{http://www.octave.org/missing.html} to learn how ", ...
+           "@url{https://www.octave.org/missing.html} to learn how ", ...
            "you can contribute missing functionality."];
     txt = __makeinfo__ (txt);
   endif
@@ -564,22 +567,47 @@ function txt = check_package (fcn, name, classes)
 
 endfunction
 
-function list = missing_functions ()
+function rlist = missing_functions ()
   persistent list = {
+  "addboundary",
   "addcats",
   "addCause",
+  "addedge",
+  "addmulti",
+  "addnode",
+  "addpoints",
+  "addRequired",
+  "addsample",
+  "addsampletocollection",
+  "addts",
+  "adjacency",
   "align",
   "alim",
   "alpha",
   "alphamap",
   "alphaShape",
+  "alphaSpectrum",
+  "alphaTriangulation",
+  "animatedline",
   "animatedLine",
+  "append",
   "array2table",
+  "array2timetable",
   "bar3",
   "bar3h",
+  "barycentricToCartesian",
+  "bctree",
   "bench",
+  "between",
+  "bfsearch",
   "bicgstabl",
+  "biconncomp",
+  "binary",
+  "binscatter",
+  "bitnot",
   "boundary",
+  "boundaryFacets",
+  "boundingbox",
   "brush",
   "builddocsearchdb",
   "bvp4c",
@@ -588,20 +616,21 @@ function list = missing_functions ()
   "bvpinit",
   "bvpset",
   "bvpxtend",
+  "caldays",
+  "caldiff",
+  "calendarDuration",
   "calllib",
   "callSoapService",
+  "calmonths",
+  "calquarters",
+  "calweeks",
+  "calyears",
   "camdolly",
   "cameratoolbar",
-  "camlookat",
-  "camorbit",
   "campan",
-  "campos",
   "camproj",
-  "camroll",
-  "camtarget",
-  "camup",
-  "camva",
-  "camzoom",
+  "cartesianToBarycentric",
+  "cartToBary",
   "categorical",
   "categories",
   "cdf2rdf",
@@ -612,70 +641,194 @@ function list = missing_functions ()
   "cdfwrite",
   "cell2table",
   "cellplot",
+  "centrality",
+  "centroid",
   "checkcode",
   "checkin",
   "checkout",
-  "clearvars",
+  "circumcenter",
+  "circumcenters",
+  "classUnderlying",
+  "clearAllMemoizedCaches",
+  "clearCache",
+  "clearpoints",
   "clipboard",
+  "clone",
   "cmopts",
+  "collapse",
   "colordef",
   "colormapeditor",
   "commandhistory",
   "commandwindow",
+  "compose",
+  "condensation",
   "coneplot",
-  "containers.Map",
+  "conncomp",
+  "contains",
   "contourslice",
-  "corrcoef",
+  "convertCharsToStrings",
+  "convertStringsToChars",
+  "convexHull",
+  "copyHDU",
+  "count",
   "countcats",
+  "countEachLabel",
   "createClassFromWsdl",
+  "createFile",
+  "createImg",
   "createSoapMessage",
+  "createTbl",
+  "criticalAlpha",
   "customverctrl",
+  "daqread",
   "datacursormode",
   "datastore",
+  "datatipinfo",
+  "dateshift",
+  "datetime",
+  "day",
+  "days",
   "dbmex",
   "dde23",
   "ddeget",
   "ddensd",
   "ddesd",
   "ddeset",
-  "decic",
+  "decomposition",
+  "degree",
   "delaunayTriangulation",
+  "deleteCol",
+  "deleteFile",
+  "deleteHDU",
+  "deleteKey",
+  "deleteproperty",
+  "deleteRecord",
+  "deleteRows",
+  "delevent",
+  "DelimitedTextImportOptions",
+  "delsample",
+  "delsamplefromcollection",
   "depdir",
   "depfun",
   "details",
+  "detectImportOptions",
   "deval",
+  "dfsearch",
   "digraph",
   "discretize",
+  "dissect",
+  "distances",
   "dither",
   "docsearch",
   "dragrect",
+  "duration",
   "dynamicprops",
   "echodemo",
+  "edgeAttachments",
+  "edges",
   "empty",
+  "enableservice",
+  "endsWith",
   "enumeration",
+  "eraseBetween",
+  "eventlisteners",
   "events",
+  "exceltime",
+  "Execute",
   "export2wsdlg",
+  "exportsetupdlg",
+  "extractAfter",
+  "extractBefore",
+  "extractBetween",
+  "faceNormal",
+  "faceNormals",
+  "fcontour",
+  "featureEdges",
+  "Feval",
+  "fewerbins",
   "figurepalette",
   "filebrowser",
+  "FileDatastore",
+  "filemarker",
+  "fileMode",
+  "fileName",
   "fill3",
+  "fillmissing",
+  "filloutliers",
+  "fimplicit",
+  "fimplicit3",
+  "findedge",
   "findgroups",
+  "findnode",
   "findprop",
   "fitsdisp",
   "fitsinfo",
   "fitsread",
   "fitswrite",
+  "FixedWidthImportOptions",
+  "flipedge",
   "flow",
+  "fmesh",
+  "fplot3",
+  "freeBoundary",
   "freqspace",
+  "fsurf",
+  "FunctionTestCase",
+  "functiontests",
   "funm",
-  "gammaincinv",
-  "getframe",
+  "gather",
+  "gcmr",
+  "geobubble",
+  "geolimits",
+  "getabstime",
+  "getAColParms",
+  "getaudiodata",
+  "getBColParms",
+  "GetCharArray",
+  "getColName",
+  "getColType",
+  "getConstantValue",
+  "getdatasamples",
+  "getdatasamplesize",
+  "getEqColType",
+  "getFileFormats",
+  "GetFullMatrix",
+  "getHdrSpace",
+  "getHDUnum",
+  "getHDUtype",
+  "getImgSize",
+  "getImgType",
+  "getinterpmethod",
+  "getnext",
+  "getNumCols",
+  "getNumHDUs",
+  "getNumInputs",
+  "getNumOutputs",
+  "getNumRows",
+  "getOpenFiles",
   "getpixelposition",
+  "getpoints",
+  "getProfiles",
+  "getqualitydesc",
   "getReport",
+  "getsamples",
+  "getsampleusingtime",
+  "gettimeseriesnames",
+  "gettsafteratevent",
+  "gettsafterevent",
+  "gettsatevent",
+  "gettsbeforeatevent",
+  "gettsbeforeevent",
+  "gettsbetweenevents",
+  "GetVariable",
+  "getvaropts",
+  "getVersion",
+  "GetWorkspaceData",
   "gobjects",
   "graph",
+  "GraphPlot",
   "graymon",
   "griddedInterpolant",
-  "gsvd",
   "guide",
   "h5create",
   "h5disp",
@@ -685,36 +838,129 @@ function list = missing_functions ()
   "h5write",
   "h5writeatt",
   "handle",
+  "hasdata",
+  "hasFrame",
+  "hasnext",
+  "hdf5info",
+  "hdf5read",
+  "hdf5write",
+  "hdfan",
+  "hdfdf24",
+  "hdfdfr8",
+  "hdfh",
+  "hdfhd",
+  "hdfhe",
+  "hdfhx",
   "hdfinfo",
+  "hdfml",
+  "hdfpt",
   "hdfread",
+  "hdftool",
+  "hdfv",
+  "hdfvf",
+  "hdfvh",
+  "hdfvs",
+  "head",
+  "heatmap",
   "height",
+  "helpbrowser",
+  "helpdesk",
+  "helpwin",
   "hgexport",
   "hgsetget",
-  "hgtransform",
+  "highlight",
   "histcounts",
   "histcounts2",
   "histogram",
   "histogram2",
+  "hms",
+  "holes",
+  "hour",
+  "hours",
+  "idealfilter",
   "im2java",
+  "ImageDatastore",
+  "imapprox",
+  "imgCompress",
   "import",
+  "imresize",
+  "incenter",
+  "incenters",
+  "incidence",
+  "indegree",
   "inmem",
   "innerjoin",
+  "inOutStatus",
+  "insertAfter",
+  "insertATbl",
+  "insertBefore",
+  "insertBTbl",
+  "insertCol",
+  "insertImg",
+  "insertRows",
+  "inShape",
   "inspect",
+  "instrcallback",
+  "instrfind",
+  "instrfindall",
+  "interfaces",
+  "interp1q",
   "interpstreamspeed",
+  "invoke",
+  "isaUnderlying",
+  "isbetween",
+  "iscalendarduration",
   "iscategorical",
   "iscategory",
+  "ischange",
+  "iscom",
+  "isCompressedImg",
+  "isConnected",
+  "isdag",
+  "isdatetime",
+  "isdst",
+  "isduration",
+  "isEdge",
   "isenum",
-  "isKey",
+  "isevent",
+  "ishole",
+  "isIllConditioned",
+  "isinterface",
+  "isinterior",
+  "isInterior",
+  "isisomorphic",
+  "islocalmax",
+  "islocalmin",
+  "isLocked",
+  "ismembertol",
   "ismissing",
+  "isnat",
+  "isomorphism",
   "isordinal",
+  "isoutlier",
   "isprotected",
-  "isstudent",
+  "isregular",
+  "issimplified",
+  "issortedrows",
+  "isStringScalar",
   "istable",
+  "istall",
+  "istimetable",
+  "isundefined",
   "isvalid",
+  "isweekend",
   "javaMethodEDT",
   "javaObjectEDT",
-  "keys",
+  "join",
+  "jsondecode",
+  "jsonencode",
+  "juliandate",
+  "labeledge",
+  "labelnode",
+  "lag",
+  "laplacian",
   "last",
+  "layout",
   "ldl",
   "libfunctions",
   "libfunctionsview",
@@ -725,34 +971,70 @@ function list = missing_functions ()
   "linkdata",
   "listfonts",
   "loadlibrary",
-  "localfunctions",
+  "lsqminnorm",
   "lsqr",
   "makehgtform",
   "mapreduce",
+  "mapreducer",
   "matfile",
+  "maxflow",
+  "MaximizeCommandWindow",
+  "maxk",
+  "maxNumCompThreads",
   "memmapfile",
+  "memoize",
+  "MemoizedFunction",
   "memory",
   "mergecats",
+  "meta.abstractDetails",
+  "meta.class.fromName",
+  "meta.DynamicProperty",
+  "meta.EnumeratedValue",
+  "meta.MetaData",
+  "meta.package.fromName",
+  "meta.package.getAllPackages",
   "methodsview",
   "MException",
   "milliseconds",
+  "MinimizeCommandWindow",
+  "mink",
   "minres",
+  "minspantree",
+  "minute",
+  "minutes",
+  "missing",
+  "mlint",
   "mlintrpt",
   "mmfileinfo",
-  "movegui",
-  "movie",
+  "month",
+  "morebins",
+  "movAbsHDU",
+  "move",
   "movie2avi",
-  "movmax",
-  "movmean",
-  "movmedian",
-  "movmin",
-  "movstd"
-  "movsum",
-  "movvar",
+  "movNamHDU",
+  "movRelHDU",
+  "mput",
   "multibandread",
   "multibandwrite",
+  "mustBeFinite",
+  "mustBeGreaterThan",
+  "mustBeGreaterThanOrEqual",
+  "mustBeInteger",
+  "mustBeLessThan",
+  "mustBeLessThanOrEqual",
+  "mustBeMember",
+  "mustBeNegative",
+  "mustBeNonempty",
+  "mustBeNonNan",
+  "mustBeNonnegative",
+  "mustBeNonpositive",
+  "mustBeNonsparse",
+  "mustBeNonzero",
+  "mustBeNumeric",
+  "mustBeNumericOrLogical",
+  "mustBePositive",
+  "mustBeReal",
   "NaT",
-  "native2unicode",
   "nccreate",
   "ncdisp",
   "ncinfo",
@@ -761,28 +1043,58 @@ function list = missing_functions ()
   "ncwrite",
   "ncwriteatt",
   "ncwriteschema",
+  "nearest",
   "nearestNeighbor",
+  "neighbors",
   "netcdf",
+  "newline",
   "noanimate",
   "notebook",
   "notify",
+  "nsidedpoly",
+  "num2ruler",
+  "numArgumentsFromSubscript",
+  "numboundaries",
+  "numedges",
+  "numnodes",
+  "numpartitions",
+  "numRegions",
+  "numsides",
+  "ode113",
+  "ode23s",
+  "ode23t",
+  "ode23tb",
   "odextend",
-  "openfig",
+  "openFile",
   "opengl",
-  "openvar",
-  "ordeig",
   "ordqz",
+  "outdegree",
   "outerjoin",
+  "pad",
+  "pagesetupdlg",
+  "parse",
   "parseSoapResponse",
   "partition",
+  "parula",
+  "path2rc",
   "pathtool",
   "pcode",
   "pdepe",
   "pdeval",
+  "perimeter",
   "plotbrowser",
   "plotedit",
   "plottools",
   "pointLocation",
+  "polaraxes",
+  "polarhistogram",
+  "polarplot",
+  "polarscatter",
+  "polybuffer",
+  "polyshape",
+  "posixtime",
+  "predecessors",
+  "preview",
   "printdlg",
   "printopt",
   "printpreview",
@@ -790,26 +1102,116 @@ function list = missing_functions ()
   "propedit",
   "properties",
   "propertyeditor",
-  "psi",
+  "PutCharArray",
+  "PutFullMatrix",
+  "PutWorkspaceData",
+  "pyargs",
+  "pyversion",
+  "quarter",
+  "Quit",
   "RandStream",
   "rbbox",
+  "readall",
+  "readasync",
+  "readATblHdr",
+  "readBTblHdr",
+  "readCard",
+  "readCol",
+  "readFrame",
+  "readimage",
+  "readImg",
+  "readKey",
+  "readKeyCmplx",
+  "readKeyDbl",
+  "readKeyLongLong",
+  "readKeyLongStr",
+  "readKeyUnit",
+  "readRecord",
   "readtable",
-  "remove",
+  "recordblocking",
+  "regions",
+  "registerevent",
+  "regmatlabserver",
+  "release",
+  "Remove",
+  "RemoveAll",
   "removecats",
+  "removets",
   "renamecats",
   "reordercats",
+  "reordernodes",
+  "replace",
+  "replaceBetween",
+  "resample",
+  "rescale",
+  "retime",
+  "reverse",
+  "rgb2gray",
+  "rlim",
+  "rmboundary",
+  "rmedge",
+  "rmholes",
+  "rmmissing",
+  "rmnode",
+  "rmslivers",
   "rng",
   "rowfun",
-  "savefig",
+  "rtickangle",
+  "rtickformat",
+  "rticklabels",
+  "ruler2num",
+  "runperf",
+  "scale",
   "scatteredInterpolant",
+  "scroll",
+  "second",
+  "seconds",
   "selectmoveresize",
   "sendmail",
   "serial",
+  "serialbreak",
+  "seriallist",
+  "setabstime",
+  "setBscale",
+  "setcats",
+  "setCompressionType",
+  "setHCompScale",
+  "setHCompSmooth",
+  "setinterpmethod",
   "setpixelposition",
+  "setstr",
+  "setTileDim",
+  "settimeseriesnames",
+  "setTscale",
+  "setuniformtime",
+  "setvaropts",
+  "setvartype",
+  "sheetnames",
+  "shortestpath",
+  "shortestpathtree",
   "showplottool",
+  "shuffle",
+  "simplify",
+  "smoothdata",
   "snapnow",
+  "sortboundaries",
+  "sortregions",
+  "sortx",
+  "sorty",
+  "split",
   "splitapply",
+  "splitEachLabel",
+  "splitlines",
+  "SpreadsheetDatastore",
+  "SpreadsheetImportOptions",
+  "ss2tf",
+  "stack",
   "standardizeMissing",
+  "startsWith",
+  "stats",
+  "step",
+  "stopasync",
+  "str2mat",
   "stream2",
   "stream3",
   "streamline",
@@ -817,80 +1219,168 @@ function list = missing_functions ()
   "streamribbon",
   "streamslice",
   "streamtube",
+  "string",
+  "strings",
+  "strip",
+  "strlength",
   "struct2table",
+  "subgraph",
+  "subtract",
   "subvolume",
+  "successors",
   "summary",
   "superclasses",
+  "support",
+  "supportPackageInstaller",
   "surf2patch",
-  "sylvester",
+  "surfaceArea",
   "symmlq",
+  "synchronize",
+  "syntax",
+  "table",
   "table2array",
   "table2cell",
   "table2struct",
+  "table2timetable",
+  "TabularTextDatastore",
+  "tail",
+  "tall",
+  "TallDatastore",
+  "tallrng",
+  "targetupdater",
+  "tcpclient",
+  "Test",
+  "TestResult",
+  "testsuite",
   "texlabel",
   "textwrap",
   "tfqmr",
+  "thetalim",
+  "thetatickformat",
+  "thetaticklabels",
   "throw",
   "throwAsCaller",
   "Tiff",
   "timeit",
   "timeofday",
   "timer",
+  "timerange",
   "timeseries",
+  "timetable",
+  "timetable2table",
   "timezones",
   "todatenum",
   "toolboxdir",
+  "topkrows",
+  "toposort",
+  "transclosure",
+  "translate",
+  "transreduction",
   "triangulation",
+  "TriRep",
+  "TriScatteredInterp",
   "tscollection",
+  "tzoffset",
+  "uialert",
+  "uiaxes",
+  "uibutton",
+  "uicheckbox",
+  "uiconfirm",
+  "uidropdown",
+  "uieditfield",
+  "uifigure",
+  "uigauge",
   "uigetpref",
   "uiimport",
+  "uiknob",
+  "uilabel",
+  "uilamp",
+  "uilistbox",
   "uiopen",
-  "uiresume",
+  "uiradiobutton",
   "uisave",
   "uisetcolor",
   "uisetfont",
   "uisetpref",
+  "uislider",
+  "uispinner",
   "uistack",
-  "uitable",
-  "uitoggletool",
-  "uitoolbar",
-  "uiwait",
+  "uiswitch",
+  "uitab",
+  "uitabgroup",
+  "uitextarea",
+  "uitogglebutton",
+  "uitree",
+  "uitreenode",
   "undocheckout",
-  "unicode2native",
+  "uniquetol",
   "unloadlibrary",
   "unmesh",
+  "unregisterallevents",
+  "unregisterevent",
   "unstack",
+  "upgradePreviouslyInstalledSupportPackages",
   "userpath",
-  "values",
+  "ValueIterator",
   "varfun",
+  "vartype",
   "verctrl",
   "verLessThan",
+  "vertexAttachments",
+  "vertexNormal",
   "VideoReader",
   "VideoWriter",
   "viewmtx",
   "visdiff",
+  "volume",
   "volumebounds",
+  "voronoiDiagram",
   "web",
+  "weboptions",
   "webread",
   "websave",
   "webwrite",
+  "week",
+  "whatsnew",
   "width",
   "winopen",
-  "winqueryreg",
+  "withtol",
+  "wordcloud",
   "workspace",
+  "write",
+  "writeChecksum",
+  "writeCol",
+  "writeComment",
+  "writeDate",
+  "writeHistory",
+  "writeImg",
+  "writeKey",
+  "writeKeyUnit",
   "writetable",
+  "writeVideo",
   "xmlread",
   "xmlwrite",
   "xslt",
+  "xtickangle",
+  "xtickformat",
+  "year",
+  "years",
+  "ymd",
+  "ytickangle",
+  "ytickformat",
+  "yyaxis",
+  "yyyymmdd",
+  "ztickangle",
+  "ztickformat",
   };
-endfunction
 
+  rlist = list;
+endfunction
 
 %!test
 %! str = __unimplemented__ ("no_name_function");
 %! assert (isempty (str));
-%! str = __unimplemented__ ("quad2d");
-%! assert (str(1:51), "quad2d is not implemented.  Consider using dblquad.");
+%! str = __unimplemented__ ("matlabrc");
+%! assert (str(1:71), "matlabrc is not implemented.  Octave uses the file '.octaverc' instead.");
 %! str = __unimplemented__ ("MException");
 %! assert (str(1:58), "the 'MException' function is not yet implemented in Octave");
-
